==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/song/models/Note.java <==
/*
 * Created on 23-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.song.models;

import java.io.Serializable;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 */
public class Note implements Component,Serializable{
    private int value;
    private long start;
    private Duration duration;
    private int velocity;
    private int string;
    private boolean tiedNote;
    private NoteEffect effect;
    private long startWidthRepetitions;
    
    public Note(int value, long start, Duration duration, int velocity,int string,boolean tiedNote,NoteEffect effect) {
        this.value = value;
        this.start = start;
        this.duration = duration;
        this.velocity = velocity;
        this.string = string;
        this.tiedNote = tiedNote;
        this.effect = effect;
        this.startWidthRepetitions = this.start;
    }

    public long getStart() {
        return start;
    }

    public void setStart(long start) {
        this.start = start;
    }

    public int getValue() {
        return value;
    }

    public void setValue(int value) {
        this.value = value;
    }

    public Duration getDuration() {
        return duration;
    }

    public void setDuration(Duration duration) {
        this.duration = duration;
    }

    public int getVelocity() {
        return velocity;
    }

    public void setVelocity(int velocity) {
        this.velocity = velocity;
    }

    public int getString() {
        return string;
    }

    public void setString(int string) {
        this.string = string;
    }
    
    public boolean isTiedNote() {
        return tiedNote;
    }
    
    public void setTiedNote(boolean tiedNote) {
        this.tiedNote = tiedNote;
    }
    


	public NoteEffect getEffect() {
        return effect;
    }
    public void setEffect(NoteEffect effect) {
        this.effect = effect;
    }
    public long getStartWidthRepetitions() {
        return startWidthRepetitions;
    }
    public void setStartWidthRepetitions(long startWidthRepetitions) {
        this.startWidthRepetitions = startWidthRepetitions;
    }    
    
    public Object clone(){
        return new Note(getValue(),getStart(),(Duration)getDuration().clone(),getVelocity(),getString(),isTiedNote(),(NoteEffect)getEffect().clone());
    }
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/song/models/Note.java <==
/*
 * Created on 23-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.song.models;

import java.io.Serializable;

/**
 * @author julian
 * 
 * TODO To change the template for this generated type comment go to Window - Preferences - Java - Code Style - Code Templates
 */
public class Note implements Component,Serializable{
    private int value;
    private long start;
    private Duration duration;
    private int velocity;
    private int string;
    private boolean tiedNote;
    private NoteEffect effect;
    private long startWithRepetitions;
    
    public Note(int value, long start, Duration duration, int velocity,int string,boolean tiedNote,NoteEffect effect) {
        this.value = value;
        this.start = start;
        this.duration = duration;
        this.velocity = velocity;
        this.string = string;
        this.tiedNote = tiedNote;
        this.effect = effect;
        this.startWithRepetitions = this.start;
    }

    public long getStart() {
        return start;
    }

    public void setStart(long start) {
        this.start = start;
    }

    public int getValue() {
        return value;
    }

    public void setValue(int value) {
        this.value = value;
    }

    public Duration getDuration() {
        return duration;
    }

    public void setDuration(Duration duration) {
        this.duration = duration;
    }

    public int getVelocity() {
        return velocity;
    }

    public void setVelocity(int velocity) {
        this.velocity = velocity;
    }

    public int getString() {
        return string;
    }

    public void setString(int string) {
        this.string = string;
    }
    
    public boolean isTiedNote() {
        return tiedNote;
    }
    
    public void setTiedNote(boolean tiedNote) {
        this.tiedNote = tiedNote;
    }
    


	public NoteEffect getEffect() {
        return effect;
    }
    public void setEffect(NoteEffect effect) {
        this.effect = effect;
    }
    public long getStartWithRepetitions() {
        return startWithRepetitions;
    }
    public void setStartWithRepetitions(long startWithRepetitions) {
        this.startWithRepetitions = startWithRepetitions;
    }    
    
    public Object clone(){
        return new Note(getValue(),getStart(),(Duration)getDuration().clone(),getVelocity(),getString(),isTiedNote(),(NoteEffect)getEffect().clone());
    }
}
